@@ -232,8 +232,12 @@ def __get_google_location(city, state, zipcode, logger):
     
     if response:
       if len(response) > 1:
-        logger.warning(f"Google returned multiple matches for {loc_str}")
-        return None
+        logger.warning(f"Google returned multiple matches for {loc_str}. Selecting a single address.")
+        selected_address = __select_address(city=city, state=state, address_list=response)
+        if not selected_address:
+          logger.warning(f"Cannot select a single address from multiple for {loc_str}.")
+          return None
+        response = [selected_address]
 
       data = __parse_response(response)
       
@@ -326,3 +330,27 @@ def __get_timezone_from_cache(timezone_cache_key, logger):
 
 def __get_timezone_cache_key(lat,lng):
   return f'{lat},{lng}'
+
+def __select_address(city, state, address_list):
+  city_and_state_list = []
+  # Parse city and state from multiple addresses
+  for address in address_list:
+    address_components = address.get('address_components', [])
+    city_and_state = {'city': None, 'state': None, 'address': address}
+    for address_component in address_components:
+      types = address_component.get('types', [])
+      if not city_and_state['city'] and ('locality' in types or 'administrative_area_level_3' in types):
+        city_and_state['city'] = address_component.get('long_name')
+      elif not city_and_state['state'] and ('country' in types or 'administrative_area_level_1' in types):
+        city_and_state['state'] = address_component.get('short_name')
+
+      if city_and_state['city'] and city_and_state['state']:
+        city_and_state_list.append(city_and_state)
+        break
+
+  # Select the address matching the input city and state
+  for parsed_city_and_state in city_and_state_list:
+    if parsed_city_and_state['city'].strip().lower() == city.strip().lower() \
+      and parsed_city_and_state['state'].strip().lower() == state.strip().lower():
+      return parsed_city_and_state['address']
+  return None
